@@ -4,5 +4,5 @@ import yaml
 
 
 def validate_yml(yml):
-    schema = requests.get('https://schema.miquido.dev').text
+    schema = requests.get('https://schema.miquido.dev', timeout=30).text
     validate(yaml.safe_load(yml), yaml.safe_load(schema))
